<?php
/**
* 2007-2016 PrestaShop
*
* NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    Metacreo <metacreo@gmail.com>
 *  @copyright 2016 metacreo
 *  @license   http://opensource.org/licenses/GPL-3.0  GNU GENERAL PUBLIC LICENSE (GPL-3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

class MakeAnOffer extends Module
{
    public $context;
    public function __construct()
    {
        $this->name = 'makeanoffer';
        $this->version = '1.5';
        $this->author = 'Metacreo';
        $this->tab = 'front_office_features';
        $this->need_instance = 0;
        $this->secure_key = Tools::encrypt($this->name);
        $this->bootstrap = true;
        $this->module_key = '03a77232202621a6060cbe124f93f672';
        parent::__construct();
        $this->displayName = $this->l('Make an Offer module');
        $this->description = $this->l('Allows customers to send a Offers to customer service.');
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }
 
    public function install()
    {
        Configuration::updateValue('MAKEANOFFER_EMAILS', Configuration::get('PS_SHOP_EMAIL'));
		Configuration::updateValue('MAKEANOFFER_QTYZERO', 1);
		Configuration::updateValue('MAKEANOFFER_ACTZERO', 0);
		Configuration::updateValue('MAKEANOFFER_EXCAT', '');
		Configuration::updateValue('MAKEANOFFER_EXPROD', '');
        return (parent::install() && $this->registerHook('displayProductButtons') && $this->registerHook('header'));
    }

    public function uninstall()
    {
        Configuration::deleteByName('MAKEANOFFER_EMAILS');
		Configuration::deleteByName('MAKEANOFFER_QTYZERO');
		Configuration::deleteByName('MAKEANOFFER_ACTZERO');
		Configuration::deleteByName('MAKEANOFFER_EXCAT');
		Configuration::deleteByName('MAKEANOFFER_EXPROD');
        return (parent::uninstall()&&$this->unregisterHook('header')&&$this->unregisterHook('displayProductButtons'));
    }

    public function hookDisplayProductButtons()
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            return;
        }
  /* Product informations */
        //$product = new Product((int)Tools::getValue('id_product'), false, $this->context->language->id);
		$product = $this->context->controller->getProduct();
        $image = Product::getCover((int)$product->id);
        $currency = new Currency($this->context->cookie->id_currency);
		$zeroqty = Configuration::get('MAKEANOFFER_QTYZERO');
		$zeroact = Configuration::get('MAKEANOFFER_ACTZERO');
		$excat = Configuration::get('MAKEANOFFER_EXCAT');
		$excatids = explode(',', $excat);
		if (in_array($product->id_category_default, $excatids)) { $cat = 1; } else { $cat = 0; };
		$exprod = Configuration::get('MAKEANOFFER_EXPROD');
		$exprodids = explode(',', $exprod);
		if (in_array($product->id, $exprodids)) { $prod = 1; } else { $prod = 0; };
        $this->context->smarty->assign(array(
        'mao_product' => $product,
        'mao_product_cover' => (int)$product->id.'-'.(int)$image['id_image'],
        'mao_secure_key' => $this->secure_key,
        'mao_currency' => $currency,
		'mao_qty' => $zeroqty,
		'mao_act' => $zeroact,
		'mao_excat' => $cat,
		'mao_exprod' => $prod
		
        ));

        return $this->display(__FILE__, '/views/templates/front/makeanoffer-extra.tpl');
    }

    public function hookHeader()
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            return;
        }
        $this->page_name = Dispatcher::getInstance()->getController();
        if ($this->page_name == 'product') {
            $this->context->controller->addCSS($this->_path.'/views/css/makeanoffer.css', 'all');
            $this->context->controller->addJS($this->_path.'/views/js/makeanoffer.js');
        }
    }
 
    public function getContent()
    {
        $output = '<h2>'.$this->displayName.'</h2>'.'
  <p>Allows customers to send a Offers to customer service or another email.</p>
  <p>Contact the author: <a href="mailto:metacreo@gmail.com">metacreo@gmail.com</a></p>
  <p>Please donate for future development of this module:</p>
  <form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
  <input type="hidden" name="cmd" value="_s-xclick">
  <input type="hidden" name="hosted_button_id" value="F8WDPKXC9KASN">
  <input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG_global.gif" border="0" 
  name="submit" alt="PayPal – The safer, easier way to pay online.">
  <img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
  </form>
  <br>';
			/////start
        if (Tools::isSubmit('submit'.$this->name)) {
            $mailers = Tools::getValue('MAKEANOFFER_EMAILS');
			$qtyzero = Tools::getValue('MAKEANOFFER_QTYZERO');
			$actzero = Tools::getValue('MAKEANOFFER_ACTZERO');
			$excat = Tools::getValue('MAKEANOFFER_EXCAT');
			$exprod = Tools::getValue('MAKEANOFFER_EXPROD');
            if (!$mailers || empty($mailers) || !Validate::isGenericName($mailers) || $qtyzero != 0 && $qtyzero != 1 || $actzero != 0 && $actzero != 1) {
                $output .= $this->displayError($this->l('Invalid Configuration value'));
            } else {
                Configuration::updateValue('MAKEANOFFER_EMAILS', $mailers);
				Configuration::updateValue('MAKEANOFFER_QTYZERO', (int)($qtyzero));
				Configuration::updateValue('MAKEANOFFER_ACTZERO', (int)($actzero));
				Configuration::updateValue('MAKEANOFFER_EXCAT', $excat);
				Configuration::updateValue('MAKEANOFFER_EXPROD', $exprod);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
			/////end
        }
        return $output.$this->renderForm();
    }

    public function renderForm()
    {
    // Get default language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');
    // Init Fields form array
        $fields_form = array(
        'form' => array(
        'legend' => array(
            'title' => $this->l('Settings'),
        ),
        'input' => array(
        array(
        'type' => 'text',
        'label' => $this->l('Recipient e-mail addresses:'),
        'name' => 'MAKEANOFFER_EMAILS',
        'desc' => $this->l('Separator comma without a space.').' (first@example.com,two@example.com,tree@example.com)',
        'required' => true
        ),
		///
        array(
        'type' => 'text',
        'label' => $this->l('Excluded categories ID:'),
        'name' => 'MAKEANOFFER_EXCAT',
        'desc' => $this->l('Separator comma without a space.').' (2,3,6)',
        'required' => false
        ),
        array(
        'type' => 'text',
        'label' => $this->l('Excluded products ID:'),
        'name' => 'MAKEANOFFER_EXPROD',
        'desc' => $this->l('Separator comma without a space.').' (5,34,15,156)',
        'required' => false
        ),
		///
        array(
        'type' => 'switch',
        'label' => $this->l('Show on pages with 0 quantity'),
        'name' => 'MAKEANOFFER_QTYZERO',
		'is_bool' => true,
		'values' => array(
						array(
						'id' => 'active_on',
						'value' => 1,
						'label' => $this->l('Enabled')
							),
						array(
						'id' => 'active_off',
						'value' => 0,
						'label' => $this->l('Disabled')
							)
						),
        	),
        array(
        'type' => 'switch',
        'label' => $this->l('Active on pages with 0 quantity'),
        'name' => 'MAKEANOFFER_ACTZERO',
		'is_bool' => true,
		'values' => array(
						array(
						'id' => 'active_on',
						'value' => 1,
						'label' => $this->l('Enabled')
							),
						array(
						'id' => 'active_off',
						'value' => 0,
						'label' => $this->l('Disabled')
							)
						),
        	),

        ),
        'submit' => array(
        'title' => $this->l('Save'),
        'class' => 'btn btn-default pull-right'
        ),
        )
        );
        $helper = new HelperForm();
    // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
    // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
    // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = false;        // false -> remove toolbar
        $helper->submit_action = 'submit'.$this->name;
    // Load current value
        $helper->fields_value['MAKEANOFFER_EMAILS'] = Configuration::get('MAKEANOFFER_EMAILS');
        $helper->fields_value['MAKEANOFFER_QTYZERO'] = Configuration::get('MAKEANOFFER_QTYZERO');
        $helper->fields_value['MAKEANOFFER_ACTZERO'] = Configuration::get('MAKEANOFFER_ACTZERO');
		$helper->fields_value['MAKEANOFFER_EXCAT'] = Configuration::get('MAKEANOFFER_EXCAT');
		$helper->fields_value['MAKEANOFFER_EXPROD'] = Configuration::get('MAKEANOFFER_EXPROD');
        return $helper->generateForm(array($fields_form));
    }
}
